## publish

mv module.r.html module.txt # change setup.py version (cd status && python -m unittest *status.py) (rm -rf dist && python3 -m build --sdist && twine upload dist/*) (git commit -am "0.0.20" && git tag 0.0.20)

## build

(cd STRUCTURE && pip install --requirement MODULES_PIP.UTF8 --target MODULES_PIP)

## status

### start

# # CHANGE UT_STATUS MODULE SELECTOR # (cd status && python -m unittest *STATUS.py)

### build

# # Add the source modules requirement modules # # These need to be the same as the "setup.py" "install_requires" # (cd STATUS && pip install --requirement STATUS_MODULES_PIP.UTF8 --target STATUS_MODULES_PIP)

### BUILD_PIP_DIST_CHECK

(cd STRUCTURE/MODULES_DIST && rm -rf *) # # INSTALL THE LATEST VERSION OF THE "BODY_SCAN" FROM PIP # (cd STRUCTURE && pip install "BODY_SCAN==0.0.17" --target MODULES_DIST)

## pertinent

https://github.com/locustio/locust pytest ward unittest